searchData={"items":[{"type":"module","title":"Jason","doc":"A blazing fast JSON parser and generator in pure Elixir.","ref":"Jason.html"},{"type":"function","title":"Jason.decode/2","doc":"Parses a JSON value from `input` iodata.","ref":"Jason.html#decode/2"},{"type":"function","title":"Options - Jason.decode/2","doc":"* `:keys` - controls how keys in objects are decoded. Possible values are:\n\n    * `:strings` (default) - decodes keys as binary strings,\n    * `:atoms` - keys are converted to atoms using `String.to_atom/1`,\n    * `:atoms!` - keys are converted to atoms using `String.to_existing_atom/1`,\n    * custom decoder - additionally a function accepting a string and returning a key\n      is accepted.\n\n  * `:strings` - controls how strings (including keys) are decoded. Possible values are:\n\n    * `:reference` (default) - when possible tries to create a sub-binary into the original\n    * `:copy` - always copies the strings. This option is especially useful when parts of the\n      decoded data will be stored for a long time (in ets or some process) to avoid keeping\n      the reference to the original data.\n\n  * `:floats` - controls how floats are decoded. Possible values are:\n\n    * `:native` (default) - Native conversion from binary to float using `:erlang.binary_to_float/1`,\n    * `:decimals` - uses `Decimal.new/1` to parse the binary into a Decimal struct with arbitrary precision.\n\n  * `:objects` - controls how objects are decoded. Possible values are:\n\n    * `:maps` (default) - objects are decoded as maps\n    * `:ordered_objects` - objects are decoded as `Jason.OrderedObject` structs","ref":"Jason.html#decode/2-options"},{"type":"function","title":"Decoding keys to atoms - Jason.decode/2","doc":"The `:atoms` option uses the `String.to_atom/1` call that can create atoms at runtime.\nSince the atoms are not garbage collected, this can pose a DoS attack vector when used\non user-controlled data.","ref":"Jason.html#decode/2-decoding-keys-to-atoms"},{"type":"function","title":"Examples - Jason.decode/2","doc":"iex> Jason.decode(\"{}\")\n    {:ok, %{}}\n\n    iex> Jason.decode(\"invalid\")\n    {:error, %Jason.DecodeError{data: \"invalid\", position: 0, token: nil}}","ref":"Jason.html#decode/2-examples"},{"type":"function","title":"Jason.decode!/2","doc":"Parses a JSON value from `input` iodata.\n\nSimilar to `decode/2` except it will unwrap the error tuple and raise\nin case of errors.","ref":"Jason.html#decode!/2"},{"type":"function","title":"Examples - Jason.decode!/2","doc":"iex> Jason.decode!(\"{}\")\n    %{}\n\n    iex> Jason.decode!(\"invalid\")\n    ** (Jason.DecodeError) unexpected byte at position 0: 0x69 (\"i\")","ref":"Jason.html#decode!/2-examples"},{"type":"function","title":"Jason.encode/2","doc":"Generates JSON corresponding to `input`.\n\nThe generation is controlled by the `Jason.Encoder` protocol,\nplease refer to the module to read more on how to define the protocol\nfor custom data types.","ref":"Jason.html#encode/2"},{"type":"function","title":"Options - Jason.encode/2","doc":"* `:escape` - controls how strings are encoded. Possible values are:\n\n    * `:json` (default) - the regular JSON escaping as defined by RFC 7159.\n    * `:javascript_safe` - additionally escapes the LINE SEPARATOR (U+2028)\n      and PARAGRAPH SEPARATOR (U+2029) characters to make the produced JSON\n      valid JavaScript.\n    * `:html_safe` - similar to `:javascript_safe`, but also escapes the `/`\n      character to prevent XSS.\n    * `:unicode_safe` - escapes all non-ascii characters.\n\n  * `:maps` - controls how maps are encoded. Possible values are:\n\n    * `:strict` - checks the encoded map for duplicate keys and raises\n      if they appear. For example `%{:foo => 1, \"foo\" => 2}` would be\n      rejected, since both keys would be encoded to the string `\"foo\"`.\n    * `:naive` (default) - does not perform the check.\n\n  * `:pretty` - controls pretty printing of the output. Possible values are:\n\n    * `true` to pretty print with default configuration\n    * a keyword of options as specified by `Jason.Formatter.pretty_print/2`.","ref":"Jason.html#encode/2-options"},{"type":"function","title":"Examples - Jason.encode/2","doc":"iex> Jason.encode(%{a: 1})\n    {:ok, ~S|{\"a\":1}|}\n\n    iex> Jason.encode(\"\\xFF\")\n    {:error, %Jason.EncodeError{message: \"invalid byte 0xFF in <<255>>\"}}","ref":"Jason.html#encode/2-examples"},{"type":"function","title":"Jason.encode!/2","doc":"Generates JSON corresponding to `input`.\n\nSimilar to `encode/1` except it will unwrap the error tuple and raise\nin case of errors.","ref":"Jason.html#encode!/2"},{"type":"function","title":"Examples - Jason.encode!/2","doc":"iex> Jason.encode!(%{a: 1})\n    ~S|{\"a\":1}|\n\n    iex> Jason.encode!(\"\\xFF\")\n    ** (Jason.EncodeError) invalid byte 0xFF in <<255>>","ref":"Jason.html#encode!/2-examples"},{"type":"function","title":"Jason.encode_to_iodata/2","doc":"Generates JSON corresponding to `input` and returns iodata.\n\nThis function should be preferred to `encode/2`, if the generated\nJSON will be handed over to one of the IO functions or sent\nover the socket. The Erlang runtime is able to leverage vectorised\nwrites and avoid allocating a continuous buffer for the whole\nresulting string, lowering memory use and increasing performance.","ref":"Jason.html#encode_to_iodata/2"},{"type":"function","title":"Examples - Jason.encode_to_iodata/2","doc":"iex> {:ok, iodata} = Jason.encode_to_iodata(%{a: 1})\n    iex> IO.iodata_to_binary(iodata)\n    ~S|{\"a\":1}|\n\n    iex> Jason.encode_to_iodata(\"\\xFF\")\n    {:error, %Jason.EncodeError{message: \"invalid byte 0xFF in <<255>>\"}}","ref":"Jason.html#encode_to_iodata/2-examples"},{"type":"function","title":"Jason.encode_to_iodata!/2","doc":"Generates JSON corresponding to `input` and returns iodata.\n\nSimilar to `encode_to_iodata/1` except it will unwrap the error tuple\nand raise in case of errors.","ref":"Jason.html#encode_to_iodata!/2"},{"type":"function","title":"Examples - Jason.encode_to_iodata!/2","doc":"iex> iodata = Jason.encode_to_iodata!(%{a: 1})\n    iex> IO.iodata_to_binary(iodata)\n    ~S|{\"a\":1}|\n\n    iex> Jason.encode_to_iodata!(\"\\xFF\")\n    ** (Jason.EncodeError) invalid byte 0xFF in <<255>>","ref":"Jason.html#encode_to_iodata!/2-examples"},{"type":"type","title":"Jason.decode_opt/0","doc":"","ref":"Jason.html#t:decode_opt/0"},{"type":"type","title":"Jason.encode_opt/0","doc":"","ref":"Jason.html#t:encode_opt/0"},{"type":"type","title":"Jason.escape/0","doc":"","ref":"Jason.html#t:escape/0"},{"type":"type","title":"Jason.floats/0","doc":"","ref":"Jason.html#t:floats/0"},{"type":"type","title":"Jason.keys/0","doc":"","ref":"Jason.html#t:keys/0"},{"type":"type","title":"Jason.maps/0","doc":"","ref":"Jason.html#t:maps/0"},{"type":"type","title":"Jason.objects/0","doc":"","ref":"Jason.html#t:objects/0"},{"type":"type","title":"Jason.strings/0","doc":"","ref":"Jason.html#t:strings/0"},{"type":"module","title":"Jason.Encode","doc":"Utilities for encoding elixir values to JSON.","ref":"Jason.Encode.html"},{"type":"function","title":"Jason.Encode.atom/2","doc":"","ref":"Jason.Encode.html#atom/2"},{"type":"function","title":"Jason.Encode.float/1","doc":"","ref":"Jason.Encode.html#float/1"},{"type":"function","title":"Jason.Encode.integer/1","doc":"","ref":"Jason.Encode.html#integer/1"},{"type":"function","title":"Jason.Encode.keyword/2","doc":"","ref":"Jason.Encode.html#keyword/2"},{"type":"function","title":"Jason.Encode.list/2","doc":"","ref":"Jason.Encode.html#list/2"},{"type":"function","title":"Jason.Encode.map/2","doc":"","ref":"Jason.Encode.html#map/2"},{"type":"function","title":"Jason.Encode.string/2","doc":"","ref":"Jason.Encode.html#string/2"},{"type":"function","title":"Jason.Encode.struct/2","doc":"","ref":"Jason.Encode.html#struct/2"},{"type":"function","title":"Jason.Encode.value/2","doc":"Equivalent to calling the `Jason.Encoder.encode/2` protocol function.\n\nSlightly more efficient for built-in types because of the internal dispatching.","ref":"Jason.Encode.html#value/2"},{"type":"opaque","title":"Jason.Encode.opts/0","doc":"","ref":"Jason.Encode.html#t:opts/0"},{"type":"protocol","title":"Jason.Encoder","doc":"Protocol controlling how a value is encoded to JSON.","ref":"Jason.Encoder.html"},{"type":"protocol","title":"Deriving - Jason.Encoder","doc":"The protocol allows leveraging the Elixir's `@derive` feature\nto simplify protocol implementation in trivial cases. Accepted\noptions are:\n\n  * `:only` - encodes only values of specified keys.\n  * `:except` - encodes all struct fields except specified keys.\n\nBy default all keys except the `:__struct__` key are encoded.","ref":"Jason.Encoder.html#module-deriving"},{"type":"protocol","title":"Example - Jason.Encoder","doc":"Let's assume a presence of the following struct:\n\n    defmodule Test do\n      defstruct [:foo, :bar, :baz]\n    end\n\nIf we were to call `@derive Jason.Encoder` just before `defstruct`,\nan implementation similar to the following implementation would be generated:\n\n    defimpl Jason.Encoder, for: Test do\n      def encode(value, opts) do\n        Jason.Encode.map(Map.take(value, [:foo, :bar, :baz]), opts)\n      end\n    end\n\nIf we called `@derive {Jason.Encoder, only: [:foo]}`, an implementation\nsimilar to the following implementation would be generated:\n\n    defimpl Jason.Encoder, for: Test do\n      def encode(value, opts) do\n        Jason.Encode.map(Map.take(value, [:foo]), opts)\n      end\n    end\n\nIf we called `@derive {Jason.Encoder, except: [:foo]}`, an implementation\nsimilar to the following implementation would be generated:\n\n    defimpl Jason.Encoder, for: Test do\n      def encode(value, opts) do\n        Jason.Encode.map(Map.take(value, [:bar, :baz]), opts)\n      end\n    end\n\nThe actually generated implementations are more efficient computing some data\nduring compilation similar to the macros from the `Jason.Helpers` module.","ref":"Jason.Encoder.html#module-example"},{"type":"protocol","title":"Explicit implementation - Jason.Encoder","doc":"If you wish to implement the protocol fully yourself, it is advised to\nuse functions from the `Jason.Encode` module to do the actual iodata\ngeneration - they are highly optimized and verified to always produce\nvalid JSON.","ref":"Jason.Encoder.html#module-explicit-implementation"},{"type":"function","title":"Jason.Encoder.encode/2","doc":"Encodes `value` to JSON.\n\nThe argument `opts` is opaque - it can be passed to various functions in\n`Jason.Encode` (or to the protocol function itself) for encoding values to JSON.","ref":"Jason.Encoder.html#encode/2"},{"type":"type","title":"Jason.Encoder.opts/0","doc":"","ref":"Jason.Encoder.html#t:opts/0"},{"type":"type","title":"Jason.Encoder.t/0","doc":"","ref":"Jason.Encoder.html#t:t/0"},{"type":"module","title":"Jason.Formatter","doc":"Pretty-printing and minimizing functions for JSON-encoded data.\n\nInput is required to be in an 8-bit-wide encoding such as UTF-8 or Latin-1\nin `t:iodata/0` format. Input must have valid JSON, invalid JSON may produce\nunexpected results or errors.","ref":"Jason.Formatter.html"},{"type":"function","title":"Jason.Formatter.minimize/2","doc":"Minimizes JSON-encoded `input`.\n\n`input` may contain multiple JSON objects or arrays, optionally\nseparated by whitespace (e.g., one object per line). Minimized\noutput will contain one object per line. No trailing newline is emitted.","ref":"Jason.Formatter.html#minimize/2"},{"type":"function","title":"Options - Jason.Formatter.minimize/2","doc":"* `:record_separator` - controls the string used as newline (default: `\"\\n\"`).","ref":"Jason.Formatter.html#minimize/2-options"},{"type":"function","title":"Examples - Jason.Formatter.minimize/2","doc":"iex> Jason.Formatter.minimize(~s|{ \"a\" : \"b\" , \"c\": \\n\\n 2}|)\n    ~s|{\"a\":\"b\",\"c\":2}|","ref":"Jason.Formatter.html#minimize/2-examples"},{"type":"function","title":"Jason.Formatter.minimize_to_iodata/2","doc":"Minimizes JSON-encoded `input` and returns iodata.\n\nThis function should be preferred to `minimize/2`, if the minimized\nJSON will be handed over to one of the IO functions or sent\nover the socket. The Erlang runtime is able to leverage vectorised\nwrites and avoid allocating a continuous buffer for the whole\nresulting string, lowering memory use and increasing performance.","ref":"Jason.Formatter.html#minimize_to_iodata/2"},{"type":"function","title":"Jason.Formatter.pretty_print/2","doc":"Pretty-prints JSON-encoded `input`.\n\n`input` may contain multiple JSON objects or arrays, optionally separated\nby whitespace (e.g., one object per line). Objects in output will be\nseparated by newlines. No trailing newline is emitted.","ref":"Jason.Formatter.html#pretty_print/2"},{"type":"function","title":"Options - Jason.Formatter.pretty_print/2","doc":"* `:indent` - used for nested objects and arrays (default: two spaces - `\"  \"`);\n  * `:line_separator` - used in nested objects (default: `\"\\n\"`);\n  * `:record_separator` - separates root-level objects and arrays\n    (default is the value for `:line_separator` option);\n  * `:after_colon` - printed after a colon inside objects (default: one space - `\" \"`).","ref":"Jason.Formatter.html#pretty_print/2-options"},{"type":"function","title":"Examples - Jason.Formatter.pretty_print/2","doc":"iex> Jason.Formatter.pretty_print(~s|{\"a\":{\"b\": [1, 2]}}|)\n    ~s|{\n      \"a\": {\n        \"b\": [\n          1,\n          2\n        ]\n      }\n    }|","ref":"Jason.Formatter.html#pretty_print/2-examples"},{"type":"function","title":"Jason.Formatter.pretty_print_to_iodata/2","doc":"Pretty-prints JSON-encoded `input` and returns iodata.\n\nThis function should be preferred to `pretty_print/2`, if the pretty-printed\nJSON will be handed over to one of the IO functions or sent\nover the socket. The Erlang runtime is able to leverage vectorised\nwrites and avoid allocating a continuous buffer for the whole\nresulting string, lowering memory use and increasing performance.","ref":"Jason.Formatter.html#pretty_print_to_iodata/2"},{"type":"type","title":"Jason.Formatter.opts/0","doc":"","ref":"Jason.Formatter.html#t:opts/0"},{"type":"module","title":"Jason.Fragment","doc":"Provides a way to inject an already-encoded JSON structure into a\nto-be-encoded structure in optimized fashion.\n\nThis avoids a decoding/encoding round-trip for the subpart.\n\nThis feature can be used for caching parts of the JSON, or delegating\nthe generation of the JSON to a third-party system (e.g. Postgres).","ref":"Jason.Fragment.html"},{"type":"function","title":"Jason.Fragment.new/1","doc":"","ref":"Jason.Fragment.html#new/1"},{"type":"module","title":"Jason.Helpers","doc":"Provides macro facilities for partial compile-time encoding of JSON.","ref":"Jason.Helpers.html"},{"type":"macro","title":"Jason.Helpers.json_map/1","doc":"Encodes a JSON map from a compile-time keyword.\n\nEncodes the keys at compile time and strives to create as flat iodata\nstructure as possible to achieve maximum efficiency. Does encoding\nright at the call site, but returns an `%Jason.Fragment{}` struct\nthat needs to be passed to one of the \"main\" encoding functions -\nfor example `Jason.encode/2` for final encoding into JSON - this\nmakes it completely transparent for most uses.\n\nOnly allows keys that do not require escaping in any of the supported\nencoding modes. This means only ASCII characters from the range\n0x1F..0x7F excluding '\\', '/' and '\"' are allowed - this also excludes\nall control characters like newlines.\n\nPreserves the order of the keys.","ref":"Jason.Helpers.html#json_map/1"},{"type":"macro","title":"Example - Jason.Helpers.json_map/1","doc":"iex> fragment = json_map(foo: 1, bar: 2)\n    iex> Jason.encode!(fragment)\n    \"{\\\"foo\\\":1,\\\"bar\\\":2}\"","ref":"Jason.Helpers.html#json_map/1-example"},{"type":"macro","title":"Jason.Helpers.json_map_take/2","doc":"Encodes a JSON map from a variable containing a map and a compile-time\nlist of keys.\n\nIt is equivalent to calling `Map.take/2` before encoding. Otherwise works\nsimilar to `json_map/2`.","ref":"Jason.Helpers.html#json_map_take/2"},{"type":"macro","title":"Example - Jason.Helpers.json_map_take/2","doc":"iex> map = %{a: 1, b: 2, c: 3}\n    iex> fragment = json_map_take(map, [:c, :b])\n    iex> Jason.encode!(fragment)\n    \"{\\\"c\\\":3,\\\"b\\\":2}\"","ref":"Jason.Helpers.html#json_map_take/2-example"},{"type":"module","title":"Jason.OrderedObject","doc":"","ref":"Jason.OrderedObject.html"},{"type":"function","title":"Jason.OrderedObject.__struct__/0","doc":"Struct implementing a JSON object retaining order of properties.\n\nA wrapper around a keyword (that supports non-atom keys) allowing for\nproper protocol implementations.\n\nImplements the `Access` behaviour and `Enumerable` protocol with\ncomplexity similar to keywords/lists.","ref":"Jason.OrderedObject.html#__struct__/0"},{"type":"function","title":"Jason.OrderedObject.new/1","doc":"","ref":"Jason.OrderedObject.html#new/1"},{"type":"type","title":"Jason.OrderedObject.t/0","doc":"","ref":"Jason.OrderedObject.html#t:t/0"},{"type":"module","title":"Jason.Sigil","doc":"","ref":"Jason.Sigil.html"},{"type":"macro","title":"Jason.Sigil.sigil_J/2","doc":"Handles the sigil `~J` for raw JSON strings.\n\nDecodes a raw string ignoring Elixir interpolations and\nescape characters at compile-time.","ref":"Jason.Sigil.html#sigil_J/2"},{"type":"macro","title":"Examples - Jason.Sigil.sigil_J/2","doc":"iex> ~J'\"#{string}\"'\n    \"\\#{string}\"\n\n    iex> ~J'\"\\u0078\\\\y\"'\n    \"x\\\\y\"\n\n    iex> ~J'{\"#{key}\": \"#{}\"}'a\n    %{\"\\#{key}\": \"\\#{}\"}","ref":"Jason.Sigil.html#sigil_J/2-examples"},{"type":"macro","title":"Jason.Sigil.sigil_j/2","doc":"Handles the sigil `~j` for JSON strings.\n\nCalls `Jason.decode!/2` with modifiers mapped to options.\n\nGiven a string literal without interpolations, decodes the\nstring at compile-time.","ref":"Jason.Sigil.html#sigil_j/2"},{"type":"macro","title":"Modifiers - Jason.Sigil.sigil_j/2","doc":"See `Jason.decode/2` for detailed descriptions.\n\n  * `a` - equivalent to `{:keys, :atoms}` option\n  * `A` - equivalent to `{:keys, :atoms!}` option\n  * `r` - equivalent to `{:strings, :reference}` option\n  * `c` - equivalent to `{:strings, :copy}` option","ref":"Jason.Sigil.html#sigil_j/2-modifiers"},{"type":"macro","title":"Examples - Jason.Sigil.sigil_j/2","doc":"iex> ~j\"0\"\n    0\n\n    iex> ~j\"[1, 2, 3]\"\n    [1, 2, 3]\n\n    iex> ~j'\"string\"'r\n    \"string\"\n\n    iex> ~j\"{}\"\n    %{}\n\n    iex> ~j'{\"atom\": \"value\"}'a\n    %{atom: \"value\"}\n\n    iex> ~j'{\"#{:j}\": #{~c'\"j\"'}}'A\n    %{j: \"j\"}","ref":"Jason.Sigil.html#sigil_j/2-examples"},{"type":"exception","title":"Jason.DecodeError","doc":"","ref":"Jason.DecodeError.html"},{"type":"function","title":"Jason.DecodeError.message/1","doc":"","ref":"Jason.DecodeError.html#message/1"},{"type":"type","title":"Jason.DecodeError.t/0","doc":"","ref":"Jason.DecodeError.html#t:t/0"},{"type":"exception","title":"Jason.EncodeError","doc":"","ref":"Jason.EncodeError.html"},{"type":"function","title":"Jason.EncodeError.new/1","doc":"","ref":"Jason.EncodeError.html#new/1"},{"type":"type","title":"Jason.EncodeError.t/0","doc":"","ref":"Jason.EncodeError.html#t:t/0"},{"type":"extras","title":"Jason","doc":"# Jason\n\nA blazing fast JSON parser and generator in pure Elixir.\n\nThe parser and generator are at least twice as fast as other Elixir/Erlang libraries\n(most notably `Poison`).\nThe performance is comparable to `jiffy`, which is implemented in C as a NIF.\nJason is usually only twice as slow.\n\nBoth parser and generator fully conform to\n[RFC 8259](https://tools.ietf.org/html/rfc8259) and\n[ECMA 404](http://www.ecma-international.org/publications/standards/Ecma-404.htm)\nstandards. The parser is tested using [JSONTestSuite](https://github.com/nst/JSONTestSuite).","ref":"readme.html"},{"type":"extras","title":"Installation - Jason","doc":"The package can be installed by adding `jason` to your list of dependencies\nin `mix.exs`:\n\n```elixir\ndef deps do\n  [{:jason, \"~> 1.4\"}]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic Usage - Jason","doc":"``` elixir\niex(1)> Jason.encode!(%{\"age\" => 44, \"name\" => \"Steve Irwin\", \"nationality\" => \"Australian\"})\n\"{\\\"age\\\":44,\\\"name\\\":\\\"Steve Irwin\\\",\\\"nationality\\\":\\\"Australian\\\"}\"\n\niex(2)> Jason.decode!(~s({\"age\":44,\"name\":\"Steve Irwin\",\"nationality\":\"Australian\"}))\n%{\"age\" => 44, \"name\" => \"Steve Irwin\", \"nationality\" => \"Australian\"}\n```\n\nFull documentation can be found at [https://hexdocs.pm/jason](https://hexdocs.pm/jason).","ref":"readme.html#basic-usage"},{"type":"extras","title":"Use with other libraries - Jason","doc":"","ref":"readme.html#use-with-other-libraries"},{"type":"extras","title":"Postgrex - Jason","doc":"Versions starting at 0.14.0 use `Jason` by default. For earlier versions, please refer to\n[previous versions of this document](https://github.com/michalmuskala/jason/tree/v1.1.2#postgrex).","ref":"readme.html#postgrex"},{"type":"extras","title":"Ecto - Jason","doc":"Versions starting at 3.0.0 use `Jason` by default. For earlier versions, please refer to\n[previous versions of this document](https://github.com/michalmuskala/jason/tree/v1.1.2#ecto).","ref":"readme.html#ecto"},{"type":"extras","title":"Plug (and Phoenix) - Jason","doc":"Phoenix starting at 1.4.0 uses `Jason` by default. For earlier versions, please refer to\n[previous versions of this document](https://github.com/michalmuskala/jason/tree/v1.1.2#plug-and-phoenix).","ref":"readme.html#plug-and-phoenix"},{"type":"extras","title":"Absinthe - Jason","doc":"You need to pass the `:json_codec` option to `Absinthe.Plug`\n\n```elixir\n# When called directly:\nplug Absinthe.Plug,\n  schema: MyApp.Schema,\n  json_codec: Jason\n\n# When used in phoenix router:\nforward \"/api\",\n  to: Absinthe.Plug,\n  init_opts: [schema: MyApp.Schema, json_codec: Jason]\n```","ref":"readme.html#absinthe"},{"type":"extras","title":"Benchmarks - Jason","doc":"Detailed benchmarks (including memory measurements):\nhttps://gist.github.com/michalmuskala/4d64a5a7696ca84ac7c169a0206640d5\n\nHTML reports for the benchmark (only performance measurements):\nhttp://michal.muskala.eu/jason/decode.html and http://michal.muskala.eu/jason/encode.html","ref":"readme.html#benchmarks"},{"type":"extras","title":"Running - Jason","doc":"Benchmarks against most popular Elixir & Erlang json libraries can be executed after\ngoing into the `bench/` folder and then executing `mix bench.encode` and `mix bench.decode`.\nA HTML report of the benchmarks (after their execution) can be found in\n`bench/output/encode.html` and `bench/output/decode.html` respectively.","ref":"readme.html#running"},{"type":"extras","title":"Differences to Poison - Jason","doc":"Jason has a couple feature differences compared to Poison.\n\n  * Jason follows the JSON spec more strictly, for example it does not allow\n    unescaped newline characters in JSON strings - e.g. `\"\\\"\\n\\\"\"` will\n    produce a decoding error.\n  * no support for decoding into data structures (the `as:` option).\n  * no built-in encoders for `MapSet`, `Range` and `Stream`.\n  * no support for encoding arbitrary structs - explicit implementation\n    of the `Jason.Encoder` protocol is always required.\n  * different pretty-printing customisation options (default `pretty: true` works the same)","ref":"readme.html#differences-to-poison"},{"type":"extras","title":"Encoders - Jason","doc":"If you require encoders for any of the unsupported collection types, I suggest\nadding the needed implementations directly to your project:\n\n```elixir\ndefimpl Jason.Encoder, for: [MapSet, Range, Stream] do\n  def encode(struct, opts) do\n    Jason.Encode.list(Enum.to_list(struct), opts)\n  end\nend\n```\n\nIf you need to encode some struct that does not implement the protocol,\nif you own the struct, you can derive the implementation specifying\nwhich fields should be encoded to JSON:\n\n```elixir\n@derive {Jason.Encoder, only: [....]}\ndefstruct # ...\n```\n\nIt is also possible to encode all fields, although this should be\nused carefully to avoid accidentally leaking private information\nwhen new fields are added:\n\n```elixir\n@derive Jason.Encoder\ndefstruct # ...\n```\n\nFinally, if you don't own the struct you want to encode to JSON,\nyou may use `Protocol.derive/3` placed outside of any module:\n\n```elixir\nProtocol.derive(Jason.Encoder, NameOfTheStruct, only: [...])\nProtocol.derive(Jason.Encoder, NameOfTheStruct)\n```","ref":"readme.html#encoders"},{"type":"extras","title":"Injecting an already encoded JSON inside a to-be-encoded structure - Jason","doc":"If parts of the to-be-encoded structure are already JSON-encoded, you can\nuse `Jason.Fragment` to mark the parts as already encoded, and avoid a\ndecoding/encoding roundtrip.\n\n```elixir\nalready_encoded_json = Jason.encode!(%{hello: \"world\"})\nJason.encode!(%{foo: Jason.Fragment.new(already_encoded_json)})\n```\n\nThis feature is especially useful if you need to cache a part of the JSON,\nor if it is already provided by another system (e.g. `jsonb_agg` with Postgres).","ref":"readme.html#injecting-an-already-encoded-json-inside-a-to-be-encoded-structure"},{"type":"extras","title":"License - Jason","doc":"Jason is released under the Apache License 2.0 - see the [LICENSE](LICENSE) file.\n\nSome elements of tests and benchmarks have their origins in the\n[Poison library](https://github.com/devinus/poison) and were initially licensed under [CC0-1.0](https://creativecommons.org/publicdomain/zero/1.0/).","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"1.4.1 (06.07.2023) - Changelog","doc":"* Add limit to decoded integer sizes of 1024 digits. This can be changed\n  with the `decoding_integer_digit_limit` app env config.","ref":"changelog.html#1-4-1-06-07-2023"},{"type":"extras","title":"1.4.0 (12.09.2022) - Changelog","doc":"","ref":"changelog.html#1-4-0-12-09-2022"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Use the `:erlang.float_to_binary(_, [:short])` function, instead of `io_lib_format.fwrite_g/1`\n  where available (OTP 24.1+). This provides equivalent output with much less memory used\n  and significantly improved performance.","ref":"changelog.html#enhancements"},{"type":"extras","title":"1.3.0 (21.12.2021) - Changelog","doc":"","ref":"changelog.html#1-3-0-21-12-2021"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add the `Jason.OrderedObject` struct\n* Support decoding objects preserving all the keys with `objects: :ordered_objects` option\n* Support decoding floats to `Decimal` with `floats: :decimals` option\n* Add `~j` and `~J` sigils in module `Jason.Sigil` to support writing JSON literals in code","ref":"changelog.html#enhancements"},{"type":"extras","title":"Fixes - Changelog","doc":"* Fix error reporting when decoding strings (it was possible to mis-attribute the offending byte)\n* Verify fields given to `@derive`","ref":"changelog.html#fixes"},{"type":"extras","title":"1.2.2 (08.09.2020) - Changelog","doc":"","ref":"changelog.html#1-2-2-08-09-2020"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support Decimal 2.0","ref":"changelog.html#enhancements"},{"type":"extras","title":"1.2.1 (04.05.2020) - Changelog","doc":"","ref":"changelog.html#1-2-1-04-05-2020"},{"type":"extras","title":"Security - Changelog","doc":"* Fix `html_safe` escaping in `Jason.encode`\n\n  The `<!--` sequence of characters would not be escaped in `Jason.encode`\n  with`html_escape` mode, which could lead to DoS attacks when used for\n  embedding of arbitrary, user controlled strings into HTML through JSON\n  (e.g. inside of ` ` tags).\n\n  If you were not using the `html_safe` option, you are not affected.\n\n  Affected versions: < 1.2.1\n  Patched versions: >= 1.2.1","ref":"changelog.html#security"},{"type":"extras","title":"1.2.0 (17.03.2020) - Changelog","doc":"","ref":"changelog.html#1-2-0-17-03-2020"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Jason.Encode.keyword/2`\n  ([cb1f26a](https://github.com/michalmuskala/jason/commit/cb1f26a)).","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Fix `Jason.Helpers.json_map/1` value expansion\n  ([70b046a](https://github.com/michalmuskala/jason/commit/70b046a)).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"1.1.2 (19.10.2018) - Changelog","doc":"","ref":"changelog.html#1-1-2-19-10-2018"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* correctly handle the `pretty: false` option\n  ([ba318c8](https://github.com/michalmuskala/jason/commit/ba318c8)).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"1.1.1 (10.07.2018) - Changelog","doc":"","ref":"changelog.html#1-1-1-10-07-2018"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* correctly handle escape sequences in strings when pretty printing\n  ([794bbe4](https://github.com/michalmuskala/jason/commit/794bbe4)).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"1.1.0 (02.07.2018) - Changelog","doc":"","ref":"changelog.html#1-1-0-02-07-2018"},{"type":"extras","title":"Enhancements - Changelog","doc":"* pretty-printing support through `Jason.Formatter` and `pretty: true` option\n  in `Jason.encode/2` ([d758e36](https://github.com/michalmuskala/jason/commit/d758e36)).","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* silence variable warnings for fields with underscores used during deriving\n  ([88dd85c](https://github.com/michalmuskala/jason/commit/88dd85c)).\n* **potential incompatibility** don't raise `Protocol.UndefinedError` in non-bang functions\n  ([ad0f57b](https://github.com/michalmuskala/jason/commit/ad0f57b)).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"1.0.1 (02.07.2018) - Changelog","doc":"","ref":"changelog.html#1-0-1-02-07-2018"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* fix `Jason.Encode.escape` type ([a57b430](https://github.com/michalmuskala/jason/commit/a57b430))\n* multiple documentation improvements","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"1.0.0 (26.01.2018) - Changelog","doc":"No changes","ref":"changelog.html#1-0-0-26-01-2018"},{"type":"extras","title":"1.0.0-rc.3 (26.01.2018) - Changelog","doc":"","ref":"changelog.html#1-0-0-rc-3-26-01-2018"},{"type":"extras","title":"Changes - Changelog","doc":"* update `escape` option of `Jason.encode/2` to take values:\n  `:json | :unicode_safe | :html_safe | :javascript_safe` for consistency. Old values of\n  `:unicode` and `:javascript` are still supported for compatibility with Poison.\n  ([f42dcbd](https://github.com/michalmuskala/jason/commit/f42dcbd))","ref":"changelog.html#changes"},{"type":"extras","title":"1.0.0-rc.2 (07.01.2018) - Changelog","doc":"","ref":"changelog.html#1-0-0-rc-2-07-01-2018"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* add type for `strings` option ([b459ee4](https://github.com/michalmuskala/jason/commit/b459ee4))\n* support iodata in `decode!` ([a1f3456](https://github.com/michalmuskala/jason/commit/a1f3456))","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"1.0.0-rc.1 (22.12.2017) - Changelog","doc":"* Initial release","ref":"changelog.html#1-0-0-rc-1-22-12-2017"},{"type":"extras","title":"LICENSE","doc":"Copyright (c) 2017-present Michał Muskała\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}